# This is a generated file! Please edit source .ksy file and use kaitai-struct-compiler to rebuild

from pkg_resources import parse_version
import kaitaistruct
from kaitaistruct import KaitaiStruct, KaitaiStream, BytesIO
import satnogsdecoders.process


if parse_version(kaitaistruct.__version__) < parse_version('0.9'):
    raise Exception("Incompatible Kaitai Struct Python API: 0.9 or later is required, but you have %s" % (kaitaistruct.__version__))

class Vzlusat2(KaitaiStruct):
    """:field csp_hdr_crc: csp_header.crc
    :field csp_hdr_rdp: csp_header.rdp
    :field csp_hdr_xtea: csp_header.xtea
    :field csp_hdr_hmac: csp_header.hmac
    :field csp_hdr_src_port: csp_header.source_port
    :field csp_hdr_dst_port: csp_header.destination_port
    :field csp_hdr_destination: csp_header.destination
    :field csp_hdr_source: csp_header.source
    :field csp_hdr_priority: csp_header.priority
    :field obc_timestamp: csp_data.payload.obc_timestamp
    :field obc_boot_count: csp_data.payload.obc_boot_count
    :field obc_reset_cause: csp_data.payload.obc_reset_cause
    :field eps_vbatt: csp_data.payload.eps_vbatt
    :field eps_cursun: csp_data.payload.eps_cursun
    :field eps_cursys: csp_data.payload.eps_cursys
    :field eps_temp_bat: csp_data.payload.eps_temp_bat
    :field radio_temp_pa: csp_data.payload.radio_temp_pa
    :field radio_tot_tx_count: csp_data.payload.radio_tot_tx_count
    :field radio_tot_rx_count: csp_data.payload.radio_tot_rx_count
    :field flag: csp_data.payload.flag
    :field chunk: csp_data.payload.chunk
    :field time: csp_data.payload.time
    :field data: csp_data.payload.data_raw.data.data_str
    """
    def __init__(self, _io, _parent=None, _root=None):
        self._io = _io
        self._parent = _parent
        self._root = _root if _root else self
        self._read()

    def _read(self):
        self.csp_header = Vzlusat2.CspHeaderT(self._io, self, self._root)
        self.csp_data = Vzlusat2.CspDataT(self._io, self, self._root)

    class CspHeaderT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.csp_header_raw = self._io.read_u4be()

        @property
        def source(self):
            if hasattr(self, '_m_source'):
                return self._m_source if hasattr(self, '_m_source') else None

            self._m_source = ((self.csp_header_raw >> 25) & 31)
            return self._m_source if hasattr(self, '_m_source') else None

        @property
        def source_port(self):
            if hasattr(self, '_m_source_port'):
                return self._m_source_port if hasattr(self, '_m_source_port') else None

            self._m_source_port = ((self.csp_header_raw >> 8) & 63)
            return self._m_source_port if hasattr(self, '_m_source_port') else None

        @property
        def destination_port(self):
            if hasattr(self, '_m_destination_port'):
                return self._m_destination_port if hasattr(self, '_m_destination_port') else None

            self._m_destination_port = ((self.csp_header_raw >> 14) & 63)
            return self._m_destination_port if hasattr(self, '_m_destination_port') else None

        @property
        def rdp(self):
            if hasattr(self, '_m_rdp'):
                return self._m_rdp if hasattr(self, '_m_rdp') else None

            self._m_rdp = ((self.csp_header_raw & 2) >> 1)
            return self._m_rdp if hasattr(self, '_m_rdp') else None

        @property
        def destination(self):
            if hasattr(self, '_m_destination'):
                return self._m_destination if hasattr(self, '_m_destination') else None

            self._m_destination = ((self.csp_header_raw >> 20) & 31)
            return self._m_destination if hasattr(self, '_m_destination') else None

        @property
        def priority(self):
            if hasattr(self, '_m_priority'):
                return self._m_priority if hasattr(self, '_m_priority') else None

            self._m_priority = (self.csp_header_raw >> 30)
            return self._m_priority if hasattr(self, '_m_priority') else None

        @property
        def reserved(self):
            if hasattr(self, '_m_reserved'):
                return self._m_reserved if hasattr(self, '_m_reserved') else None

            self._m_reserved = ((self.csp_header_raw >> 4) & 15)
            return self._m_reserved if hasattr(self, '_m_reserved') else None

        @property
        def xtea(self):
            if hasattr(self, '_m_xtea'):
                return self._m_xtea if hasattr(self, '_m_xtea') else None

            self._m_xtea = ((self.csp_header_raw & 4) >> 2)
            return self._m_xtea if hasattr(self, '_m_xtea') else None

        @property
        def hmac(self):
            if hasattr(self, '_m_hmac'):
                return self._m_hmac if hasattr(self, '_m_hmac') else None

            self._m_hmac = ((self.csp_header_raw & 8) >> 3)
            return self._m_hmac if hasattr(self, '_m_hmac') else None

        @property
        def crc(self):
            if hasattr(self, '_m_crc'):
                return self._m_crc if hasattr(self, '_m_crc') else None

            self._m_crc = (self.csp_header_raw & 1)
            return self._m_crc if hasattr(self, '_m_crc') else None


    class CspDataT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.cmd = self._io.read_u1()
            if  ((self._parent.csp_header.source == 1) and (self._parent.csp_header.destination == 26) and (self._parent.csp_header.source_port == 18) and (self._parent.csp_header.destination_port == 18)) :
                _on = self.cmd
                if _on == 86:
                    self.payload = Vzlusat2.Vzlusat2BeaconT(self._io, self, self._root)
                elif _on == 3:
                    self.payload = Vzlusat2.Vzlusat2DropT(self._io, self, self._root)



    class Vzlusat2BeaconT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.callsign = self._io.read_bytes(8)
            if not self.callsign == b"\x5A\x4C\x55\x53\x41\x54\x2D\x32":
                raise kaitaistruct.ValidationNotEqualError(b"\x5A\x4C\x55\x53\x41\x54\x2D\x32", self.callsign, self._io, u"/types/vzlusat2_beacon_t/seq/0")
            self.obc_timestamp = self._io.read_u4be()
            self.obc_boot_count = self._io.read_u4be()
            self.obc_reset_cause = self._io.read_u4be()
            self.eps_vbatt = self._io.read_u2be()
            self.eps_cursun = self._io.read_u2be()
            self.eps_cursys = self._io.read_u2be()
            self.eps_temp_bat = self._io.read_s2be()
            self.radio_temp_pa_raw = self._io.read_s2be()
            self.radio_tot_tx_count = self._io.read_u4be()
            self.radio_tot_rx_count = self._io.read_u4be()

        @property
        def radio_temp_pa(self):
            if hasattr(self, '_m_radio_temp_pa'):
                return self._m_radio_temp_pa if hasattr(self, '_m_radio_temp_pa') else None

            self._m_radio_temp_pa = (0.1 * self.radio_temp_pa_raw)
            return self._m_radio_temp_pa if hasattr(self, '_m_radio_temp_pa') else None


    class Vzlusat2DropT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.flag = self._io.read_u1()
            self.chunk = self._io.read_u4be()
            self.time = self._io.read_u4be()
            self._raw_data_raw = self._io.read_bytes_full()
            _io__raw_data_raw = KaitaiStream(BytesIO(self._raw_data_raw))
            self.data_raw = Vzlusat2.Vzlusat2DropT.DataB64(_io__raw_data_raw, self, self._root)

        class DataB64(KaitaiStruct):
            def __init__(self, _io, _parent=None, _root=None):
                self._io = _io
                self._parent = _parent
                self._root = _root if _root else self
                self._read()

            def _read(self):
                self._raw__raw_data = self._io.read_bytes_full()
                _process = satnogsdecoders.process.B64encode()
                self._raw_data = _process.decode(self._raw__raw_data)
                _io__raw_data = KaitaiStream(BytesIO(self._raw_data))
                self.data = Vzlusat2.Vzlusat2DropT.StrB64(_io__raw_data, self, self._root)


        class StrB64(KaitaiStruct):
            def __init__(self, _io, _parent=None, _root=None):
                self._io = _io
                self._parent = _parent
                self._root = _root if _root else self
                self._read()

            def _read(self):
                self.data_str = (self._io.read_bytes_full()).decode(u"ASCII")







# This is a generated file! Please edit source .ksy file and use kaitai-struct-compiler to rebuild

from pkg_resources import parse_version
import kaitaistruct
from kaitaistruct import KaitaiStruct, KaitaiStream, BytesIO


if parse_version(kaitaistruct.__version__) < parse_version('0.9'):
    raise Exception("Incompatible Kaitai Struct Python API: 0.9 or later is required, but you have %s" % (kaitaistruct.__version__))

class Gt1(KaitaiStruct):
    """:field dest_callsign: ax25_frame.ax25_header.dest_callsign_raw.callsign_ror.callsign
    :field src_callsign: ax25_frame.ax25_header.src_callsign_raw.callsign_ror.callsign
    :field src_ssid: ax25_frame.ax25_header.src_ssid_raw.ssid
    :field dest_ssid: ax25_frame.ax25_header.dest_ssid_raw.ssid
    :field ctl: ax25_frame.ax25_header.ctl
    :field pid: ax25_frame.payload.pid
    :field packet_type: ax25_frame.payload.data_payload.packet_type
    :field sys_time1: ax25_frame.payload.data_payload.data_payload.sys_time1
    :field switch_status: ax25_frame.payload.data_payload.data_payload.switch_status
    :field currentstate: ax25_frame.payload.data_payload.data_payload.currentstate
    :field startingstate: ax25_frame.payload.data_payload.data_payload.startingstate
    :field kissnuminvaliddownlinks: ax25_frame.payload.data_payload.data_payload.kissnuminvaliddownlinks
    :field kissnuminvaliduplinks: ax25_frame.payload.data_payload.data_payload.kissnuminvaliduplinks
    :field commandsdispatched: ax25_frame.payload.data_payload.data_payload.commandsdispatched
    :field commanderrors: ax25_frame.payload.data_payload.data_payload.commanderrors
    :field raw_value_atmega: ax25_frame.payload.data_payload.data_payload.raw_value_atmega
    :field raw_value_sp1: ax25_frame.payload.data_payload.data_payload.raw_value_sp1
    :field raw_value_sp2: ax25_frame.payload.data_payload.data_payload.raw_value_sp2
    :field raw_value_sp3: ax25_frame.payload.data_payload.data_payload.raw_value_sp3
    :field raw_value_sp4: ax25_frame.payload.data_payload.data_payload.raw_value_sp4
    :field time_remaining_0: ax25_frame.payload.data_payload.data_payload.time_remaining_0
    :field time_remaining_1: ax25_frame.payload.data_payload.data_payload.time_remaining_1
    :field timer_length_0: ax25_frame.payload.data_payload.data_payload.timer_length_0
    :field timer_length_1: ax25_frame.payload.data_payload.data_payload.timer_length_1
    :field atmegarobot_interactions: ax25_frame.payload.data_payload.data_payload.atmegarobot_interactions
    :field beacon_interval: ax25_frame.payload.data_payload.data_payload.beacon_interval
    :field beacon_separation: ax25_frame.payload.data_payload.data_payload.beacon_separation
    :field burn_wire_duration: ax25_frame.payload.data_payload.data_payload.burn_wire_duration
    :field burn_wire_attempts: ax25_frame.payload.data_payload.data_payload.burn_wire_attempts
    :field timer_length: ax25_frame.payload.data_payload.data_payload.timer_length
    :field magfield_x: ax25_frame.payload.data_payload.data_payload.magfield_x
    :field magfield_y: ax25_frame.payload.data_payload.data_payload.magfield_y
    :field magfield_z: ax25_frame.payload.data_payload.data_payload.magfield_z
    :field scale_factor: ax25_frame.payload.data_payload.data_payload.scale_factor
    :field reference_voltage: ax25_frame.payload.data_payload.data_payload.reference_voltage
    :field rgmaxtime_1hz: ax25_frame.payload.data_payload.data_payload.rgmaxtime_1hz
    :field rgcycleslips_1hz: ax25_frame.payload.data_payload.data_payload.rgcycleslips_1hz
    :field rgmaxtime_2hz: ax25_frame.payload.data_payload.data_payload.rgmaxtime_2hz
    :field rgcycleslips_2hz: ax25_frame.payload.data_payload.data_payload.rgcycleslips_2hz
    :field rgmaxtime_10hz: ax25_frame.payload.data_payload.data_payload.rgmaxtime_10hz
    :field rgcycleslips_10hz: ax25_frame.payload.data_payload.data_payload.rgcycleslips_10hz
    :field uart0_bytes_sent: ax25_frame.payload.data_payload.data_payload.uart0_bytes_sent
    :field uart0_bytes_recv: ax25_frame.payload.data_payload.data_payload.uart0_bytes_recv
    :field shiftregdata: ax25_frame.payload.data_payload.data_payload.shiftregdata
    :field eps_i2c_errors: ax25_frame.payload.data_payload.data_payload.eps_i2c_errors
    :field eps_vbatt_critical: ax25_frame.payload.data_payload.data_payload.eps_vbatt_critical
    :field config2_batt_maxvoltage: ax25_frame.payload.data_payload.data_payload.config2_batt_maxvoltage
    :field config2_batt_safevoltage: ax25_frame.payload.data_payload.data_payload.config2_batt_safevoltage
    :field config2_batt_criticalvoltage: ax25_frame.payload.data_payload.data_payload.config2_batt_criticalvoltage
    :field config2_batt_normalvoltage: ax25_frame.payload.data_payload.data_payload.config2_batt_normalvoltage
    :field sys_time2: ax25_frame.payload.data_payload.data_payload.sys_time2
    :field hk1_vboost1: ax25_frame.payload.data_payload.data_payload.hk1_vboost1
    :field hk1_vboost2: ax25_frame.payload.data_payload.data_payload.hk1_vboost2
    :field hk1_vboost3: ax25_frame.payload.data_payload.data_payload.hk1_vboost3
    :field hk1_vbatt: ax25_frame.payload.data_payload.data_payload.hk1_vbatt
    :field hk1_vcurin1: ax25_frame.payload.data_payload.data_payload.hk1_vcurin1
    :field hk1_vcurin2: ax25_frame.payload.data_payload.data_payload.hk1_vcurin2
    :field hk1_vcurin3: ax25_frame.payload.data_payload.data_payload.hk1_vcurin3
    :field hk1_vcursun: ax25_frame.payload.data_payload.data_payload.hk1_vcursun
    :field hk1_vcursys: ax25_frame.payload.data_payload.data_payload.hk1_vcursys
    :field hk1_vcurout1: ax25_frame.payload.data_payload.data_payload.hk1_vcurout1
    :field hk1_vcurout2: ax25_frame.payload.data_payload.data_payload.hk1_vcurout2
    :field hk1_vcurout3: ax25_frame.payload.data_payload.data_payload.hk1_vcurout3
    :field hk1_vcurout4: ax25_frame.payload.data_payload.data_payload.hk1_vcurout4
    :field hk1_vcurout5: ax25_frame.payload.data_payload.data_payload.hk1_vcurout5
    :field hk1_vcurout6: ax25_frame.payload.data_payload.data_payload.hk1_vcurout6
    :field hk1_output1: ax25_frame.payload.data_payload.data_payload.hk1_output1
    :field hk1_output2: ax25_frame.payload.data_payload.data_payload.hk1_output2
    :field hk1_output3: ax25_frame.payload.data_payload.data_payload.hk1_output3
    :field hk1_output4: ax25_frame.payload.data_payload.data_payload.hk1_output4
    :field hk1_output5: ax25_frame.payload.data_payload.data_payload.hk1_output5
    :field hk1_output6: ax25_frame.payload.data_payload.data_payload.hk1_output6
    :field hk1_output7: ax25_frame.payload.data_payload.data_payload.hk1_output7
    :field hk1_output8: ax25_frame.payload.data_payload.data_payload.hk1_output8
    :field hk1_latchup1: ax25_frame.payload.data_payload.data_payload.hk1_latchup1
    :field hk1_latchup2: ax25_frame.payload.data_payload.data_payload.hk1_latchup2
    :field hk1_latchup3: ax25_frame.payload.data_payload.data_payload.hk1_latchup3
    :field hk1_latchup4: ax25_frame.payload.data_payload.data_payload.hk1_latchup4
    :field hk1_latchup5: ax25_frame.payload.data_payload.data_payload.hk1_latchup5
    :field hk1_latchup6: ax25_frame.payload.data_payload.data_payload.hk1_latchup6
    :field hk1_wdt_i2c_time_left: ax25_frame.payload.data_payload.data_payload.hk1_wdt_i2c_time_left
    :field hk1_wdt_gnd_time_left: ax25_frame.payload.data_payload.data_payload.hk1_wdt_gnd_time_left
    :field hk1_counter_wdt_i2c: ax25_frame.payload.data_payload.data_payload.hk1_counter_wdt_i2c
    :field hk1_counter_wdt_gnd: ax25_frame.payload.data_payload.data_payload.hk1_counter_wdt_gnd
    :field hk1_counter_boot: ax25_frame.payload.data_payload.data_payload.hk1_counter_boot
    :field hk1_temp1: ax25_frame.payload.data_payload.data_payload.hk1_temp1
    :field hk1_temp2: ax25_frame.payload.data_payload.data_payload.hk1_temp2
    :field hk1_temp3: ax25_frame.payload.data_payload.data_payload.hk1_temp3
    :field hk1_temp4: ax25_frame.payload.data_payload.data_payload.hk1_temp4
    :field hk1_temp5: ax25_frame.payload.data_payload.data_payload.hk1_temp5
    :field hk1_temp6: ax25_frame.payload.data_payload.data_payload.hk1_temp6
    :field hk1_bootcause: ax25_frame.payload.data_payload.data_payload.hk1_bootcause
    :field hk1_battmode: ax25_frame.payload.data_payload.data_payload.hk1_battmode
    :field hk1_pptmode: ax25_frame.payload.data_payload.data_payload.hk1_pptmode
    :field hk1_config1_ppt_mode: ax25_frame.payload.data_payload.data_payload.hk1_config1_ppt_mode
    :field hk1_config1_battheater_mode: ax25_frame.payload.data_payload.data_payload.hk1_config1_battheater_mode
    :field hk1_config1_battheater_low: ax25_frame.payload.data_payload.data_payload.hk1_config1_battheater_low
    :field hk1_config1_battheater_high: ax25_frame.payload.data_payload.data_payload.hk1_config1_battheater_high
    """
    def __init__(self, _io, _parent=None, _root=None):
        self._io = _io
        self._parent = _parent
        self._root = _root if _root else self
        self._read()

    def _read(self):
        self.ax25_frame = Gt1.Ax25Frame(self._io, self, self._root)

    class Ax25Frame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ax25_header = Gt1.Ax25Header(self._io, self, self._root)
            _on = (self.ax25_header.ctl & 19)
            if _on == 0:
                self.payload = Gt1.IFrame(self._io, self, self._root)
            elif _on == 3:
                self.payload = Gt1.UiFrame(self._io, self, self._root)
            elif _on == 19:
                self.payload = Gt1.UiFrame(self._io, self, self._root)
            elif _on == 16:
                self.payload = Gt1.IFrame(self._io, self, self._root)
            elif _on == 18:
                self.payload = Gt1.IFrame(self._io, self, self._root)
            elif _on == 2:
                self.payload = Gt1.IFrame(self._io, self, self._root)


    class Ax25Header(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.dest_callsign_raw = Gt1.CallsignRaw(self._io, self, self._root)
            self.dest_ssid_raw = Gt1.SsidMask(self._io, self, self._root)
            self.src_callsign_raw = Gt1.CallsignRaw(self._io, self, self._root)
            self.src_ssid_raw = Gt1.SsidMask(self._io, self, self._root)
            self.ctl = self._io.read_u1()


    class UiFrame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pid = self._io.read_u1()
            self.data_payload = Gt1.Gt1Payload(self._io, self, self._root)


    class Callsign(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.callsign = (self._io.read_bytes(6)).decode(u"ASCII")
            if not  ((self.callsign == u"KK4UVG") or (self.callsign == u"KN4ZNS") or (self.callsign == u"W4AQL ")) :
                raise kaitaistruct.ValidationNotAnyOfError(self.callsign, self._io, u"/types/callsign/seq/0")


    class IFrame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pid = self._io.read_u1()
            self.ax25_info = self._io.read_bytes_full()


    class SsidMask(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ssid_mask = self._io.read_u1()

        @property
        def ssid(self):
            if hasattr(self, '_m_ssid'):
                return self._m_ssid if hasattr(self, '_m_ssid') else None

            self._m_ssid = ((self.ssid_mask & 15) >> 1)
            return self._m_ssid if hasattr(self, '_m_ssid') else None


    class Gt1payload2(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.sys_time2 = self._io.read_u4le()
            self.hk1_vboost1 = self._io.read_u2le()
            self.hk1_vboost2 = self._io.read_u2le()
            self.hk1_vboost3 = self._io.read_u2le()
            self.hk1_vbatt = self._io.read_u2le()
            self.hk1_vcurin1 = self._io.read_u2le()
            self.hk1_vcurin2 = self._io.read_u2le()
            self.hk1_vcurin3 = self._io.read_u2le()
            self.hk1_vcursun = self._io.read_u2le()
            self.hk1_vcursys = self._io.read_u2le()
            self.hk1_vcurout1 = self._io.read_u2le()
            self.hk1_vcurout2 = self._io.read_u2le()
            self.hk1_vcurout3 = self._io.read_u2le()
            self.hk1_vcurout4 = self._io.read_u2le()
            self.hk1_vcurout5 = self._io.read_u2le()
            self.hk1_vcurout6 = self._io.read_u2le()
            self.hk1_output1 = self._io.read_u1()
            self.hk1_output2 = self._io.read_u1()
            self.hk1_output3 = self._io.read_u1()
            self.hk1_output4 = self._io.read_u1()
            self.hk1_output5 = self._io.read_u1()
            self.hk1_output6 = self._io.read_u1()
            self.hk1_output7 = self._io.read_u1()
            self.hk1_output8 = self._io.read_u1()
            self.hk1_latchup1 = self._io.read_u2le()
            self.hk1_latchup2 = self._io.read_u2le()
            self.hk1_latchup3 = self._io.read_u2le()
            self.hk1_latchup4 = self._io.read_u2le()
            self.hk1_latchup5 = self._io.read_u2le()
            self.hk1_latchup6 = self._io.read_u2le()
            self.hk1_wdt_i2c_time_left = self._io.read_u4le()
            self.hk1_wdt_gnd_time_left = self._io.read_u4le()
            self.hk1_counter_wdt_i2c = self._io.read_u4le()
            self.hk1_counter_wdt_gnd = self._io.read_u4le()
            self.hk1_counter_boot = self._io.read_u4le()
            self.hk1_temp1 = self._io.read_s2le()
            self.hk1_temp2 = self._io.read_s2le()
            self.hk1_temp3 = self._io.read_s2le()
            self.hk1_temp4 = self._io.read_s2le()
            self.hk1_temp5 = self._io.read_s2le()
            self.hk1_temp6 = self._io.read_s2le()
            self.hk1_bootcause = self._io.read_u1()
            self.hk1_battmode = self._io.read_u1()
            self.hk1_pptmode = self._io.read_u1()
            self.hk1_config1_ppt_mode = self._io.read_u1()
            self.hk1_config1_battheater_mode = self._io.read_u1()
            self.hk1_config1_battheater_low = self._io.read_s1()
            self.hk1_config1_battheater_high = self._io.read_s1()


    class CallsignRaw(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self._raw__raw_callsign_ror = self._io.read_bytes(6)
            self._raw_callsign_ror = KaitaiStream.process_rotate_left(self._raw__raw_callsign_ror, 8 - (1), 1)
            _io__raw_callsign_ror = KaitaiStream(BytesIO(self._raw_callsign_ror))
            self.callsign_ror = Gt1.Callsign(_io__raw_callsign_ror, self, self._root)


    class Gt1payload1(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.sys_time1 = self._io.read_u4le()
            self.switch_status = self._io.read_u1()
            self.currentstate = self._io.read_u4le()
            self.startingstate = self._io.read_u4le()
            self.kissnuminvaliddownlinks = self._io.read_u4le()
            self.kissnuminvaliduplinks = self._io.read_u4le()
            self.commandsdispatched = self._io.read_u4le()
            self.commanderrors = self._io.read_u4le()
            self.raw_value_atmega = self._io.read_u2le()
            self.raw_value_sp1 = self._io.read_u2le()
            self.raw_value_sp2 = self._io.read_u2le()
            self.raw_value_sp3 = self._io.read_u2le()
            self.raw_value_sp4 = self._io.read_u2le()
            self.time_remaining_0 = self._io.read_u4le()
            self.time_remaining_1 = self._io.read_u4le()
            self.timer_length_0 = self._io.read_u4le()
            self.timer_length_1 = self._io.read_u4le()
            self.atmegarobot_interactions = self._io.read_u4le()
            self.beacon_interval = self._io.read_u2le()
            self.beacon_separation = self._io.read_u2le()
            self.burn_wire_duration = self._io.read_u1()
            self.burn_wire_attempts = self._io.read_u1()
            self.timer_length = self._io.read_u2le()
            self.magfield_x = self._io.read_f4le()
            self.magfield_y = self._io.read_f4le()
            self.magfield_z = self._io.read_f4le()
            self.scale_factor = self._io.read_f4le()
            self.reference_voltage = self._io.read_f4le()
            self.rgmaxtime_1hz = self._io.read_u4le()
            self.rgcycleslips_1hz = self._io.read_u4le()
            self.rgmaxtime_2hz = self._io.read_u4le()
            self.rgcycleslips_2hz = self._io.read_u4le()
            self.rgmaxtime_10hz = self._io.read_u4le()
            self.rgcycleslips_10hz = self._io.read_u4le()
            self.uart0_bytes_sent = self._io.read_u4le()
            self.uart0_bytes_recv = self._io.read_u4le()
            self.shiftregdata = self._io.read_u4le()
            self.eps_i2c_errors = self._io.read_u2le()
            self.eps_vbatt_critical = self._io.read_u2le()
            self.config2_batt_maxvoltage = self._io.read_u2le()
            self.config2_batt_safevoltage = self._io.read_u2le()
            self.config2_batt_criticalvoltage = self._io.read_u2le()
            self.config2_batt_normalvoltage = self._io.read_u2le()


    class Gt1Payload(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.packet_type = self._io.read_u1()
            _on = self.packet_type
            if _on == 1:
                self.data_payload = Gt1.Gt1payload1(self._io, self, self._root)
            elif _on == 2:
                self.data_payload = Gt1.Gt1payload2(self._io, self, self._root)






# This is a generated file! Please edit source .ksy file and use kaitai-struct-compiler to rebuild

from pkg_resources import parse_version
import kaitaistruct
from kaitaistruct import KaitaiStruct, KaitaiStream, BytesIO


if parse_version(kaitaistruct.__version__) < parse_version('0.9'):
    raise Exception("Incompatible Kaitai Struct Python API: 0.9 or later is required, but you have %s" % (kaitaistruct.__version__))

class Eshail2(KaitaiStruct):
    """:field ao40_beacon_type: ao40_frame.ao40_coding.ao40_beacon_type
    :field ao40_message_line1: ao40_frame.ao40_coding.ao40_beacon_data.ao40_message_line1
    :field ao40_message_line2: ao40_frame.ao40_coding.ao40_beacon_data.ao40_message_line2
    :field ao40_message_line3: ao40_frame.ao40_coding.ao40_beacon_data.ao40_message_line3
    :field ao40_message_line4: ao40_frame.ao40_coding.ao40_beacon_data.ao40_message_line4
    :field ao40_message_line5: ao40_frame.ao40_coding.ao40_beacon_data.ao40_message_line5
    :field ao40_message_line6: ao40_frame.ao40_coding.ao40_beacon_data.ao40_message_line6
    :field ao40_message_line7: ao40_frame.ao40_coding.ao40_beacon_data.ao40_message_line7
    :field ao40_message_line8: ao40_frame.ao40_coding.ao40_beacon_data.ao40_message_line8
    :field uptime: ao40_frame.ao40_coding.ao40_beacon_data.uptime
    :field commands: ao40_frame.ao40_coding.ao40_beacon_data.commands
    :field leila_req: ao40_frame.ao40_coding.ao40_beacon_data.leila_req
    :field leila_act: ao40_frame.ao40_coding.ao40_beacon_data.leila_act
    :field temperature: ao40_frame.ao40_coding.ao40_beacon_data.temperature
    :field volt_1: ao40_frame.ao40_coding.ao40_beacon_data.volt_1
    :field volt_2: ao40_frame.ao40_coding.ao40_beacon_data.volt_2
    :field volt_3: ao40_frame.ao40_coding.ao40_beacon_data.volt_3
    :field volt_4: ao40_frame.ao40_coding.ao40_beacon_data.volt_4
    :field volt_5: ao40_frame.ao40_coding.ao40_beacon_data.volt_5
    :field volt_6: ao40_frame.ao40_coding.ao40_beacon_data.volt_6
    :field volt_7: ao40_frame.ao40_coding.ao40_beacon_data.volt_7
    :field volt_8: ao40_frame.ao40_coding.ao40_beacon_data.volt_8
    :field volt_9: ao40_frame.ao40_coding.ao40_beacon_data.volt_9
    
    .. seealso::
       Source - https://amsat-dl.org/wp-content/uploads/2019/01/tlmspec.pdf
    """
    def __init__(self, _io, _parent=None, _root=None):
        self._io = _io
        self._parent = _parent
        self._root = _root if _root else self
        self._read()

    def _read(self):
        self.ao40_frame = Eshail2.Ao40Frame(self._io, self, self._root)

    class Ao40FecMessageSpare(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ao40_message_line1 = (self._io.read_bytes(64)).decode(u"ASCII")
            self.ao40_message_line2 = (self._io.read_bytes(64)).decode(u"ASCII")
            self.ao40_message_line3 = (self._io.read_bytes(64)).decode(u"ASCII")
            self.ao40_message_line4 = (self._io.read_bytes(64)).decode(u"ASCII")


    class Ao40Frame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            _on = self._root.frame_length
            if _on == 256:
                self.ao40_coding = Eshail2.Ao40FrameFec(self._io, self, self._root)
            elif _on == 514:
                self.ao40_coding = Eshail2.Ao40FrameUncoded(self._io, self, self._root)


    class Ao40CommandResponse(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ao40_message_line1 = (self._io.read_bytes(64)).decode(u"ASCII")
            self.ao40_message_line2 = (self._io.read_bytes(64)).decode(u"ASCII")
            self.ao40_message_line3 = (self._io.read_bytes(64)).decode(u"ASCII")
            self.ao40_message_line4 = (self._io.read_bytes(64)).decode(u"ASCII")
            self.ao40_message_line5 = (self._io.read_bytes(64)).decode(u"ASCII")
            self.ao40_message_line6 = (self._io.read_bytes(64)).decode(u"ASCII")
            self.ao40_message_line7 = (self._io.read_bytes(64)).decode(u"ASCII")
            self.ao40_message_line8 = (self._io.read_bytes(64)).decode(u"ASCII")


    class Ao40FrameUncoded(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            _on = self.ao40_beacon_type
            if _on == 77:
                self.ao40_beacon_data = Eshail2.Ao40MessageSpare(self._io, self, self._root)
            elif _on == 69:
                self.ao40_beacon_data = Eshail2.Ao40MessageSpare(self._io, self, self._root)
            elif _on == 88:
                self.ao40_beacon_data = Eshail2.Ao40MessageSpare(self._io, self, self._root)
            elif _on == 78:
                self.ao40_beacon_data = Eshail2.Ao40MessageSpare(self._io, self, self._root)
            elif _on == 65:
                self.ao40_beacon_data = Eshail2.Ao40MessageSpare(self._io, self, self._root)
            elif _on == 76:
                self.ao40_beacon_data = Eshail2.Ao40MessageL(self._io, self, self._root)
            elif _on == 68:
                self.ao40_beacon_data = Eshail2.Ao40MessageSpare(self._io, self, self._root)
            elif _on == 75:
                self.ao40_beacon_data = Eshail2.Ao40MessageK(self._io, self, self._root)
            else:
                self.ao40_beacon_data = Eshail2.Ao40CommandResponse(self._io, self, self._root)
            self.crc = self._io.read_u2be()

        @property
        def ao40_beacon_type(self):
            if hasattr(self, '_m_ao40_beacon_type'):
                return self._m_ao40_beacon_type if hasattr(self, '_m_ao40_beacon_type') else None

            _pos = self._io.pos()
            self._io.seek(0)
            self._m_ao40_beacon_type = self._io.read_u1()
            self._io.seek(_pos)
            return self._m_ao40_beacon_type if hasattr(self, '_m_ao40_beacon_type') else None


    class Ao40FecMessageL(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ao40_message_line1 = (self._io.read_bytes(64)).decode(u"ASCII")
            self.ao40_message_line2 = (self._io.read_bytes(64)).decode(u"ASCII")
            self.ao40_message_line3 = (self._io.read_bytes(64)).decode(u"ASCII")
            self.ao40_message_line4 = (self._io.read_bytes(64)).decode(u"ASCII")


    class Ao40FrameFec(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            _on = self.ao40_beacon_type
            if _on == 77:
                self.ao40_beacon_data = Eshail2.Ao40FecMessageSpare(self._io, self, self._root)
            elif _on == 69:
                self.ao40_beacon_data = Eshail2.Ao40FecMessageSpare(self._io, self, self._root)
            elif _on == 88:
                self.ao40_beacon_data = Eshail2.Ao40FecMessageSpare(self._io, self, self._root)
            elif _on == 78:
                self.ao40_beacon_data = Eshail2.Ao40FecMessageSpare(self._io, self, self._root)
            elif _on == 65:
                self.ao40_beacon_data = Eshail2.Ao40FecMessageSpare(self._io, self, self._root)
            elif _on == 76:
                self.ao40_beacon_data = Eshail2.Ao40FecMessageL(self._io, self, self._root)
            elif _on == 68:
                self.ao40_beacon_data = Eshail2.Ao40FecMessageSpare(self._io, self, self._root)
            elif _on == 75:
                self.ao40_beacon_data = Eshail2.Ao40FecMessageK(self._io, self, self._root)
            else:
                self.ao40_beacon_data = Eshail2.Ao40FecCommandResponse(self._io, self, self._root)

        @property
        def ao40_beacon_type(self):
            if hasattr(self, '_m_ao40_beacon_type'):
                return self._m_ao40_beacon_type if hasattr(self, '_m_ao40_beacon_type') else None

            _pos = self._io.pos()
            self._io.seek(0)
            self._m_ao40_beacon_type = self._io.read_u1()
            self._io.seek(_pos)
            return self._m_ao40_beacon_type if hasattr(self, '_m_ao40_beacon_type') else None


    class Ao40MessageSpare(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ao40_message_line1 = (self._io.read_bytes(64)).decode(u"ASCII")
            self.ao40_message_line2 = (self._io.read_bytes(64)).decode(u"ASCII")
            self.ao40_message_line3 = (self._io.read_bytes(64)).decode(u"ASCII")
            self.ao40_message_line4 = (self._io.read_bytes(64)).decode(u"ASCII")
            self.ao40_message_line5 = (self._io.read_bytes(64)).decode(u"ASCII")
            self.ao40_message_line6 = (self._io.read_bytes(64)).decode(u"ASCII")
            self.ao40_message_line7 = (self._io.read_bytes(64)).decode(u"ASCII")
            self.ao40_message_line8 = (self._io.read_bytes(64)).decode(u"ASCII")


    class Ao40MessageL(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ao40_message_line1 = (self._io.read_bytes(64)).decode(u"ASCII")
            self.ao40_message_line2 = (self._io.read_bytes(64)).decode(u"ASCII")
            self.ao40_message_line3 = (self._io.read_bytes(64)).decode(u"ASCII")
            self.ao40_message_line4 = (self._io.read_bytes(64)).decode(u"ASCII")
            self.ao40_message_line5 = (self._io.read_bytes(64)).decode(u"ASCII")
            self.ao40_message_line6 = (self._io.read_bytes(64)).decode(u"ASCII")
            self.ao40_message_line7 = (self._io.read_bytes(64)).decode(u"ASCII")
            self.ao40_message_line8 = (self._io.read_bytes(64)).decode(u"ASCII")


    class Ao40FecMessageK(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ao40_message_line1 = (self._io.read_bytes(64)).decode(u"ASCII")
            self.ao40_message_line2 = (self._io.read_bytes(64)).decode(u"ASCII")
            self.ao40_message_line3 = (self._io.read_bytes(64)).decode(u"ASCII")
            self.ao40_message_line4 = (self._io.read_bytes(64)).decode(u"ASCII")

        @property
        def tfl_str(self):
            if hasattr(self, '_m_tfl_str'):
                return self._m_tfl_str if hasattr(self, '_m_tfl_str') else None

            _pos = self._io.pos()
            self._io.seek(201)
            self._m_tfl_str = self._io.read_u1()
            self._io.seek(_pos)
            return self._m_tfl_str if hasattr(self, '_m_tfl_str') else None

        @property
        def volts_str_9(self):
            if hasattr(self, '_m_volts_str_9'):
                return self._m_volts_str_9 if hasattr(self, '_m_volts_str_9') else None

            _pos = self._io.pos()
            self._io.seek(182)
            self._m_volts_str_9 = [None] * (3)
            for i in range(3):
                self._m_volts_str_9[i] = self._io.read_u1()

            self._io.seek(_pos)
            return self._m_volts_str_9 if hasattr(self, '_m_volts_str_9') else None

        @property
        def leila_act(self):
            if hasattr(self, '_m_leila_act'):
                return self._m_leila_act if hasattr(self, '_m_leila_act') else None

            self._m_leila_act = self.leila_active_str > 48
            return self._m_leila_act if hasattr(self, '_m_leila_act') else None

        @property
        def volt_3(self):
            if hasattr(self, '_m_volt_3'):
                return self._m_volt_3 if hasattr(self, '_m_volt_3') else None

            self._m_volt_3 = (((self.volts_str_3[0] - 48) * 1.0) + ((self.volts_str_3[2] - 48) / 10.0))
            return self._m_volt_3 if hasattr(self, '_m_volt_3') else None

        @property
        def uptime_dd_str(self):
            if hasattr(self, '_m_uptime_dd_str'):
                return self._m_uptime_dd_str if hasattr(self, '_m_uptime_dd_str') else None

            _pos = self._io.pos()
            self._io.seek(71)
            self._m_uptime_dd_str = [None] * (2)
            for i in range(2):
                self._m_uptime_dd_str[i] = self._io.read_u1()

            self._io.seek(_pos)
            return self._m_uptime_dd_str if hasattr(self, '_m_uptime_dd_str') else None

        @property
        def volts_str_2(self):
            if hasattr(self, '_m_volts_str_2'):
                return self._m_volts_str_2 if hasattr(self, '_m_volts_str_2') else None

            _pos = self._io.pos()
            self._io.seek(154)
            self._m_volts_str_2 = [None] * (3)
            for i in range(3):
                self._m_volts_str_2[i] = self._io.read_u1()

            self._io.seek(_pos)
            return self._m_volts_str_2 if hasattr(self, '_m_volts_str_2') else None

        @property
        def commands(self):
            if hasattr(self, '_m_commands'):
                return self._m_commands if hasattr(self, '_m_commands') else None

            self._m_commands = ((((((1 if self.commands_str[0] > 47 else 0) * (self.commands_str[0] - 48)) * 1000) + (((1 if self.commands_str[1] > 47 else 0) * (self.commands_str[1] - 48)) * 100)) + (((1 if self.commands_str[2] > 47 else 0) * (self.commands_str[2] - 48)) * 10)) + (self.commands_str[3] - 48))
            return self._m_commands if hasattr(self, '_m_commands') else None

        @property
        def volt_8(self):
            if hasattr(self, '_m_volt_8'):
                return self._m_volt_8 if hasattr(self, '_m_volt_8') else None

            self._m_volt_8 = (((self.volts_str_8[0] - 48) * 1.0) + ((self.volts_str_8[2] - 48) / 10.0))
            return self._m_volt_8 if hasattr(self, '_m_volt_8') else None

        @property
        def volts_str_8(self):
            if hasattr(self, '_m_volts_str_8'):
                return self._m_volts_str_8 if hasattr(self, '_m_volts_str_8') else None

            _pos = self._io.pos()
            self._io.seek(178)
            self._m_volts_str_8 = [None] * (3)
            for i in range(3):
                self._m_volts_str_8[i] = self._io.read_u1()

            self._io.seek(_pos)
            return self._m_volts_str_8 if hasattr(self, '_m_volts_str_8') else None

        @property
        def volts_str_6(self):
            if hasattr(self, '_m_volts_str_6'):
                return self._m_volts_str_6 if hasattr(self, '_m_volts_str_6') else None

            _pos = self._io.pos()
            self._io.seek(170)
            self._m_volts_str_6 = [None] * (3)
            for i in range(3):
                self._m_volts_str_6[i] = self._io.read_u1()

            self._io.seek(_pos)
            return self._m_volts_str_6 if hasattr(self, '_m_volts_str_6') else None

        @property
        def tfh_str(self):
            if hasattr(self, '_m_tfh_str'):
                return self._m_tfh_str if hasattr(self, '_m_tfh_str') else None

            _pos = self._io.pos()
            self._io.seek(222)
            self._m_tfh_str = self._io.read_u1()
            self._io.seek(_pos)
            return self._m_tfh_str if hasattr(self, '_m_tfh_str') else None

        @property
        def volt_7(self):
            if hasattr(self, '_m_volt_7'):
                return self._m_volt_7 if hasattr(self, '_m_volt_7') else None

            self._m_volt_7 = (((self.volts_str_7[0] - 48) * 1.0) + ((self.volts_str_7[2] - 48) / 10.0))
            return self._m_volt_7 if hasattr(self, '_m_volt_7') else None

        @property
        def commands_str(self):
            if hasattr(self, '_m_commands_str'):
                return self._m_commands_str if hasattr(self, '_m_commands_str') else None

            _pos = self._io.pos()
            self._io.seek(90)
            self._m_commands_str = [None] * (4)
            for i in range(4):
                self._m_commands_str[i] = self._io.read_u1()

            self._io.seek(_pos)
            return self._m_commands_str if hasattr(self, '_m_commands_str') else None

        @property
        def volts_str_7(self):
            if hasattr(self, '_m_volts_str_7'):
                return self._m_volts_str_7 if hasattr(self, '_m_volts_str_7') else None

            _pos = self._io.pos()
            self._io.seek(174)
            self._m_volts_str_7 = [None] * (3)
            for i in range(3):
                self._m_volts_str_7[i] = self._io.read_u1()

            self._io.seek(_pos)
            return self._m_volts_str_7 if hasattr(self, '_m_volts_str_7') else None

        @property
        def hth_str(self):
            if hasattr(self, '_m_hth_str'):
                return self._m_hth_str if hasattr(self, '_m_hth_str') else None

            _pos = self._io.pos()
            self._io.seek(245)
            self._m_hth_str = self._io.read_u1()
            self._io.seek(_pos)
            return self._m_hth_str if hasattr(self, '_m_hth_str') else None

        @property
        def temperature(self):
            if hasattr(self, '_m_temperature'):
                return self._m_temperature if hasattr(self, '_m_temperature') else None

            self._m_temperature = ((((1 if self.temp_str[0] > 47 else 0) * (self.temp_str[0] - 48)) * 10) + (self.temp_str[1] - 48))
            return self._m_temperature if hasattr(self, '_m_temperature') else None

        @property
        def uptime_hh_str(self):
            if hasattr(self, '_m_uptime_hh_str'):
                return self._m_uptime_hh_str if hasattr(self, '_m_uptime_hh_str') else None

            _pos = self._io.pos()
            self._io.seek(75)
            self._m_uptime_hh_str = [None] * (2)
            for i in range(2):
                self._m_uptime_hh_str[i] = self._io.read_u1()

            self._io.seek(_pos)
            return self._m_uptime_hh_str if hasattr(self, '_m_uptime_hh_str') else None

        @property
        def volt_9(self):
            if hasattr(self, '_m_volt_9'):
                return self._m_volt_9 if hasattr(self, '_m_volt_9') else None

            self._m_volt_9 = (((self.volts_str_9[0] - 48) * 1.0) + ((self.volts_str_9[2] - 48) / 10.0))
            return self._m_volt_9 if hasattr(self, '_m_volt_9') else None

        @property
        def volts_str_4(self):
            if hasattr(self, '_m_volts_str_4'):
                return self._m_volts_str_4 if hasattr(self, '_m_volts_str_4') else None

            _pos = self._io.pos()
            self._io.seek(162)
            self._m_volts_str_4 = [None] * (3)
            for i in range(3):
                self._m_volts_str_4[i] = self._io.read_u1()

            self._io.seek(_pos)
            return self._m_volts_str_4 if hasattr(self, '_m_volts_str_4') else None

        @property
        def volt_2(self):
            if hasattr(self, '_m_volt_2'):
                return self._m_volt_2 if hasattr(self, '_m_volt_2') else None

            self._m_volt_2 = (((self.volts_str_2[0] - 48) * 1.0) + ((self.volts_str_2[2] - 48) / 10.0))
            return self._m_volt_2 if hasattr(self, '_m_volt_2') else None

        @property
        def leila_request_str(self):
            if hasattr(self, '_m_leila_request_str'):
                return self._m_leila_request_str if hasattr(self, '_m_leila_request_str') else None

            _pos = self._io.pos()
            self._io.seek(110)
            self._m_leila_request_str = self._io.read_u1()
            self._io.seek(_pos)
            return self._m_leila_request_str if hasattr(self, '_m_leila_request_str') else None

        @property
        def leila_req(self):
            if hasattr(self, '_m_leila_req'):
                return self._m_leila_req if hasattr(self, '_m_leila_req') else None

            self._m_leila_req = self.leila_request_str > 48
            return self._m_leila_req if hasattr(self, '_m_leila_req') else None

        @property
        def volt_4(self):
            if hasattr(self, '_m_volt_4'):
                return self._m_volt_4 if hasattr(self, '_m_volt_4') else None

            self._m_volt_4 = (((self.volts_str_4[0] - 48) * 1.0) + ((self.volts_str_4[2] - 48) / 10.0))
            return self._m_volt_4 if hasattr(self, '_m_volt_4') else None

        @property
        def leila_active_str(self):
            if hasattr(self, '_m_leila_active_str'):
                return self._m_leila_active_str if hasattr(self, '_m_leila_active_str') else None

            _pos = self._io.pos()
            self._io.seek(127)
            self._m_leila_active_str = self._io.read_u1()
            self._io.seek(_pos)
            return self._m_leila_active_str if hasattr(self, '_m_leila_active_str') else None

        @property
        def volts_str_5(self):
            if hasattr(self, '_m_volts_str_5'):
                return self._m_volts_str_5 if hasattr(self, '_m_volts_str_5') else None

            _pos = self._io.pos()
            self._io.seek(166)
            self._m_volts_str_5 = [None] * (3)
            for i in range(3):
                self._m_volts_str_5[i] = self._io.read_u1()

            self._io.seek(_pos)
            return self._m_volts_str_5 if hasattr(self, '_m_volts_str_5') else None

        @property
        def volt_1(self):
            if hasattr(self, '_m_volt_1'):
                return self._m_volt_1 if hasattr(self, '_m_volt_1') else None

            self._m_volt_1 = (((self.volts_str_1[0] - 48) * 1.0) + ((self.volts_str_1[2] - 48) / 10.0))
            return self._m_volt_1 if hasattr(self, '_m_volt_1') else None

        @property
        def uptime_mm_str(self):
            if hasattr(self, '_m_uptime_mm_str'):
                return self._m_uptime_mm_str if hasattr(self, '_m_uptime_mm_str') else None

            _pos = self._io.pos()
            self._io.seek(79)
            self._m_uptime_mm_str = [None] * (2)
            for i in range(2):
                self._m_uptime_mm_str[i] = self._io.read_u1()

            self._io.seek(_pos)
            return self._m_uptime_mm_str if hasattr(self, '_m_uptime_mm_str') else None

        @property
        def tfe_str(self):
            if hasattr(self, '_m_tfe_str'):
                return self._m_tfe_str if hasattr(self, '_m_tfe_str') else None

            _pos = self._io.pos()
            self._io.seek(212)
            self._m_tfe_str = self._io.read_u1()
            self._io.seek(_pos)
            return self._m_tfe_str if hasattr(self, '_m_tfe_str') else None

        @property
        def temp_str(self):
            if hasattr(self, '_m_temp_str'):
                return self._m_temp_str if hasattr(self, '_m_temp_str') else None

            _pos = self._io.pos()
            self._io.seek(134)
            self._m_temp_str = [None] * (2)
            for i in range(2):
                self._m_temp_str[i] = self._io.read_u1()

            self._io.seek(_pos)
            return self._m_temp_str if hasattr(self, '_m_temp_str') else None

        @property
        def volts_str_3(self):
            if hasattr(self, '_m_volts_str_3'):
                return self._m_volts_str_3 if hasattr(self, '_m_volts_str_3') else None

            _pos = self._io.pos()
            self._io.seek(158)
            self._m_volts_str_3 = [None] * (3)
            for i in range(3):
                self._m_volts_str_3[i] = self._io.read_u1()

            self._io.seek(_pos)
            return self._m_volts_str_3 if hasattr(self, '_m_volts_str_3') else None

        @property
        def volt_6(self):
            if hasattr(self, '_m_volt_6'):
                return self._m_volt_6 if hasattr(self, '_m_volt_6') else None

            self._m_volt_6 = (((self.volts_str_6[0] - 48) * 1.0) + ((self.volts_str_6[2] - 48) / 10.0))
            return self._m_volt_6 if hasattr(self, '_m_volt_6') else None

        @property
        def volt_5(self):
            if hasattr(self, '_m_volt_5'):
                return self._m_volt_5 if hasattr(self, '_m_volt_5') else None

            self._m_volt_5 = (((self.volts_str_5[0] - 48) * 1.0) + ((self.volts_str_5[2] - 48) / 10.0))
            return self._m_volt_5 if hasattr(self, '_m_volt_5') else None

        @property
        def uptime(self):
            if hasattr(self, '_m_uptime'):
                return self._m_uptime if hasattr(self, '_m_uptime') else None

            self._m_uptime = (((((((((1 if self.uptime_dd_str[0] > 47 else 0) * (self.uptime_dd_str[0] - 48)) * 10) + (self.uptime_dd_str[1] - 48)) * 24) * 60) * 60) + ((((((1 if self.uptime_hh_str[0] > 47 else 0) * (self.uptime_hh_str[0] - 48)) * 10) + (self.uptime_hh_str[1] - 48)) * 60) * 60)) + (((((1 if self.uptime_mm_str[0] > 47 else 0) * (self.uptime_mm_str[0] - 48)) * 10) + (self.uptime_mm_str[1] - 48)) * 60))
            return self._m_uptime if hasattr(self, '_m_uptime') else None

        @property
        def volts_str_1(self):
            if hasattr(self, '_m_volts_str_1'):
                return self._m_volts_str_1 if hasattr(self, '_m_volts_str_1') else None

            _pos = self._io.pos()
            self._io.seek(150)
            self._m_volts_str_1 = [None] * (3)
            for i in range(3):
                self._m_volts_str_1[i] = self._io.read_u1()

            self._io.seek(_pos)
            return self._m_volts_str_1 if hasattr(self, '_m_volts_str_1') else None

        @property
        def hff_str(self):
            if hasattr(self, '_m_hff_str'):
                return self._m_hff_str if hasattr(self, '_m_hff_str') else None

            _pos = self._io.pos()
            self._io.seek(234)
            self._m_hff_str = self._io.read_u1()
            self._io.seek(_pos)
            return self._m_hff_str if hasattr(self, '_m_hff_str') else None

        @property
        def hr_str(self):
            if hasattr(self, '_m_hr_str'):
                return self._m_hr_str if hasattr(self, '_m_hr_str') else None

            _pos = self._io.pos()
            self._io.seek(255)
            self._m_hr_str = self._io.read_u1()
            self._io.seek(_pos)
            return self._m_hr_str if hasattr(self, '_m_hr_str') else None


    class Ao40FecCommandResponse(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ao40_message_line1 = (self._io.read_bytes(64)).decode(u"ASCII")
            self.ao40_message_line2 = (self._io.read_bytes(64)).decode(u"ASCII")
            self.ao40_message_line3 = (self._io.read_bytes(64)).decode(u"ASCII")
            self.ao40_message_line4 = (self._io.read_bytes(64)).decode(u"ASCII")


    class Ao40MessageK(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ao40_message_line1 = (self._io.read_bytes(64)).decode(u"ASCII")
            self.ao40_message_line2 = (self._io.read_bytes(64)).decode(u"ASCII")
            self.ao40_message_line3 = (self._io.read_bytes(64)).decode(u"ASCII")
            self.ao40_message_line4 = (self._io.read_bytes(64)).decode(u"ASCII")
            self.ao40_message_line5 = (self._io.read_bytes(64)).decode(u"ASCII")
            self.ao40_message_line6 = (self._io.read_bytes(64)).decode(u"ASCII")
            self.ao40_message_line7 = (self._io.read_bytes(64)).decode(u"ASCII")
            self.ao40_message_line8 = (self._io.read_bytes(64)).decode(u"ASCII")

        @property
        def tfl_str(self):
            if hasattr(self, '_m_tfl_str'):
                return self._m_tfl_str if hasattr(self, '_m_tfl_str') else None

            _pos = self._io.pos()
            self._io.seek(201)
            self._m_tfl_str = self._io.read_u1()
            self._io.seek(_pos)
            return self._m_tfl_str if hasattr(self, '_m_tfl_str') else None

        @property
        def volts_str_9(self):
            if hasattr(self, '_m_volts_str_9'):
                return self._m_volts_str_9 if hasattr(self, '_m_volts_str_9') else None

            _pos = self._io.pos()
            self._io.seek(182)
            self._m_volts_str_9 = [None] * (3)
            for i in range(3):
                self._m_volts_str_9[i] = self._io.read_u1()

            self._io.seek(_pos)
            return self._m_volts_str_9 if hasattr(self, '_m_volts_str_9') else None

        @property
        def leila_act(self):
            if hasattr(self, '_m_leila_act'):
                return self._m_leila_act if hasattr(self, '_m_leila_act') else None

            self._m_leila_act = self.leila_active_str > 48
            return self._m_leila_act if hasattr(self, '_m_leila_act') else None

        @property
        def volt_3(self):
            if hasattr(self, '_m_volt_3'):
                return self._m_volt_3 if hasattr(self, '_m_volt_3') else None

            self._m_volt_3 = (((self.volts_str_3[0] - 48) * 1.0) + ((self.volts_str_3[2] - 48) / 10.0))
            return self._m_volt_3 if hasattr(self, '_m_volt_3') else None

        @property
        def uptime_dd_str(self):
            if hasattr(self, '_m_uptime_dd_str'):
                return self._m_uptime_dd_str if hasattr(self, '_m_uptime_dd_str') else None

            _pos = self._io.pos()
            self._io.seek(71)
            self._m_uptime_dd_str = [None] * (2)
            for i in range(2):
                self._m_uptime_dd_str[i] = self._io.read_u1()

            self._io.seek(_pos)
            return self._m_uptime_dd_str if hasattr(self, '_m_uptime_dd_str') else None

        @property
        def volts_str_2(self):
            if hasattr(self, '_m_volts_str_2'):
                return self._m_volts_str_2 if hasattr(self, '_m_volts_str_2') else None

            _pos = self._io.pos()
            self._io.seek(154)
            self._m_volts_str_2 = [None] * (3)
            for i in range(3):
                self._m_volts_str_2[i] = self._io.read_u1()

            self._io.seek(_pos)
            return self._m_volts_str_2 if hasattr(self, '_m_volts_str_2') else None

        @property
        def commands(self):
            if hasattr(self, '_m_commands'):
                return self._m_commands if hasattr(self, '_m_commands') else None

            self._m_commands = ((((((1 if self.commands_str[0] > 47 else 0) * (self.commands_str[0] - 48)) * 1000) + (((1 if self.commands_str[1] > 47 else 0) * (self.commands_str[1] - 48)) * 100)) + (((1 if self.commands_str[2] > 47 else 0) * (self.commands_str[2] - 48)) * 10)) + (self.commands_str[3] - 48))
            return self._m_commands if hasattr(self, '_m_commands') else None

        @property
        def volt_8(self):
            if hasattr(self, '_m_volt_8'):
                return self._m_volt_8 if hasattr(self, '_m_volt_8') else None

            self._m_volt_8 = (((self.volts_str_8[0] - 48) * 1.0) + ((self.volts_str_8[2] - 48) / 10.0))
            return self._m_volt_8 if hasattr(self, '_m_volt_8') else None

        @property
        def volts_str_8(self):
            if hasattr(self, '_m_volts_str_8'):
                return self._m_volts_str_8 if hasattr(self, '_m_volts_str_8') else None

            _pos = self._io.pos()
            self._io.seek(178)
            self._m_volts_str_8 = [None] * (3)
            for i in range(3):
                self._m_volts_str_8[i] = self._io.read_u1()

            self._io.seek(_pos)
            return self._m_volts_str_8 if hasattr(self, '_m_volts_str_8') else None

        @property
        def volts_str_6(self):
            if hasattr(self, '_m_volts_str_6'):
                return self._m_volts_str_6 if hasattr(self, '_m_volts_str_6') else None

            _pos = self._io.pos()
            self._io.seek(170)
            self._m_volts_str_6 = [None] * (3)
            for i in range(3):
                self._m_volts_str_6[i] = self._io.read_u1()

            self._io.seek(_pos)
            return self._m_volts_str_6 if hasattr(self, '_m_volts_str_6') else None

        @property
        def tfh_str(self):
            if hasattr(self, '_m_tfh_str'):
                return self._m_tfh_str if hasattr(self, '_m_tfh_str') else None

            _pos = self._io.pos()
            self._io.seek(222)
            self._m_tfh_str = self._io.read_u1()
            self._io.seek(_pos)
            return self._m_tfh_str if hasattr(self, '_m_tfh_str') else None

        @property
        def volt_7(self):
            if hasattr(self, '_m_volt_7'):
                return self._m_volt_7 if hasattr(self, '_m_volt_7') else None

            self._m_volt_7 = (((self.volts_str_7[0] - 48) * 1.0) + ((self.volts_str_7[2] - 48) / 10.0))
            return self._m_volt_7 if hasattr(self, '_m_volt_7') else None

        @property
        def commands_str(self):
            if hasattr(self, '_m_commands_str'):
                return self._m_commands_str if hasattr(self, '_m_commands_str') else None

            _pos = self._io.pos()
            self._io.seek(90)
            self._m_commands_str = [None] * (4)
            for i in range(4):
                self._m_commands_str[i] = self._io.read_u1()

            self._io.seek(_pos)
            return self._m_commands_str if hasattr(self, '_m_commands_str') else None

        @property
        def volts_str_7(self):
            if hasattr(self, '_m_volts_str_7'):
                return self._m_volts_str_7 if hasattr(self, '_m_volts_str_7') else None

            _pos = self._io.pos()
            self._io.seek(174)
            self._m_volts_str_7 = [None] * (3)
            for i in range(3):
                self._m_volts_str_7[i] = self._io.read_u1()

            self._io.seek(_pos)
            return self._m_volts_str_7 if hasattr(self, '_m_volts_str_7') else None

        @property
        def hth_str(self):
            if hasattr(self, '_m_hth_str'):
                return self._m_hth_str if hasattr(self, '_m_hth_str') else None

            _pos = self._io.pos()
            self._io.seek(245)
            self._m_hth_str = self._io.read_u1()
            self._io.seek(_pos)
            return self._m_hth_str if hasattr(self, '_m_hth_str') else None

        @property
        def temperature(self):
            if hasattr(self, '_m_temperature'):
                return self._m_temperature if hasattr(self, '_m_temperature') else None

            self._m_temperature = ((((1 if self.temp_str[0] > 47 else 0) * (self.temp_str[0] - 48)) * 10) + (self.temp_str[1] - 48))
            return self._m_temperature if hasattr(self, '_m_temperature') else None

        @property
        def uptime_hh_str(self):
            if hasattr(self, '_m_uptime_hh_str'):
                return self._m_uptime_hh_str if hasattr(self, '_m_uptime_hh_str') else None

            _pos = self._io.pos()
            self._io.seek(75)
            self._m_uptime_hh_str = [None] * (2)
            for i in range(2):
                self._m_uptime_hh_str[i] = self._io.read_u1()

            self._io.seek(_pos)
            return self._m_uptime_hh_str if hasattr(self, '_m_uptime_hh_str') else None

        @property
        def volt_9(self):
            if hasattr(self, '_m_volt_9'):
                return self._m_volt_9 if hasattr(self, '_m_volt_9') else None

            self._m_volt_9 = (((self.volts_str_9[0] - 48) * 1.0) + ((self.volts_str_9[2] - 48) / 10.0))
            return self._m_volt_9 if hasattr(self, '_m_volt_9') else None

        @property
        def volts_str_4(self):
            if hasattr(self, '_m_volts_str_4'):
                return self._m_volts_str_4 if hasattr(self, '_m_volts_str_4') else None

            _pos = self._io.pos()
            self._io.seek(162)
            self._m_volts_str_4 = [None] * (3)
            for i in range(3):
                self._m_volts_str_4[i] = self._io.read_u1()

            self._io.seek(_pos)
            return self._m_volts_str_4 if hasattr(self, '_m_volts_str_4') else None

        @property
        def volt_2(self):
            if hasattr(self, '_m_volt_2'):
                return self._m_volt_2 if hasattr(self, '_m_volt_2') else None

            self._m_volt_2 = (((self.volts_str_2[0] - 48) * 1.0) + ((self.volts_str_2[2] - 48) / 10.0))
            return self._m_volt_2 if hasattr(self, '_m_volt_2') else None

        @property
        def leila_request_str(self):
            if hasattr(self, '_m_leila_request_str'):
                return self._m_leila_request_str if hasattr(self, '_m_leila_request_str') else None

            _pos = self._io.pos()
            self._io.seek(110)
            self._m_leila_request_str = self._io.read_u1()
            self._io.seek(_pos)
            return self._m_leila_request_str if hasattr(self, '_m_leila_request_str') else None

        @property
        def leila_req(self):
            if hasattr(self, '_m_leila_req'):
                return self._m_leila_req if hasattr(self, '_m_leila_req') else None

            self._m_leila_req = self.leila_request_str > 48
            return self._m_leila_req if hasattr(self, '_m_leila_req') else None

        @property
        def volt_4(self):
            if hasattr(self, '_m_volt_4'):
                return self._m_volt_4 if hasattr(self, '_m_volt_4') else None

            self._m_volt_4 = (((self.volts_str_4[0] - 48) * 1.0) + ((self.volts_str_4[2] - 48) / 10.0))
            return self._m_volt_4 if hasattr(self, '_m_volt_4') else None

        @property
        def leila_active_str(self):
            if hasattr(self, '_m_leila_active_str'):
                return self._m_leila_active_str if hasattr(self, '_m_leila_active_str') else None

            _pos = self._io.pos()
            self._io.seek(127)
            self._m_leila_active_str = self._io.read_u1()
            self._io.seek(_pos)
            return self._m_leila_active_str if hasattr(self, '_m_leila_active_str') else None

        @property
        def volts_str_5(self):
            if hasattr(self, '_m_volts_str_5'):
                return self._m_volts_str_5 if hasattr(self, '_m_volts_str_5') else None

            _pos = self._io.pos()
            self._io.seek(166)
            self._m_volts_str_5 = [None] * (3)
            for i in range(3):
                self._m_volts_str_5[i] = self._io.read_u1()

            self._io.seek(_pos)
            return self._m_volts_str_5 if hasattr(self, '_m_volts_str_5') else None

        @property
        def volt_1(self):
            if hasattr(self, '_m_volt_1'):
                return self._m_volt_1 if hasattr(self, '_m_volt_1') else None

            self._m_volt_1 = (((self.volts_str_1[0] - 48) * 1.0) + ((self.volts_str_1[2] - 48) / 10.0))
            return self._m_volt_1 if hasattr(self, '_m_volt_1') else None

        @property
        def uptime_mm_str(self):
            if hasattr(self, '_m_uptime_mm_str'):
                return self._m_uptime_mm_str if hasattr(self, '_m_uptime_mm_str') else None

            _pos = self._io.pos()
            self._io.seek(79)
            self._m_uptime_mm_str = [None] * (2)
            for i in range(2):
                self._m_uptime_mm_str[i] = self._io.read_u1()

            self._io.seek(_pos)
            return self._m_uptime_mm_str if hasattr(self, '_m_uptime_mm_str') else None

        @property
        def tfe_str(self):
            if hasattr(self, '_m_tfe_str'):
                return self._m_tfe_str if hasattr(self, '_m_tfe_str') else None

            _pos = self._io.pos()
            self._io.seek(212)
            self._m_tfe_str = self._io.read_u1()
            self._io.seek(_pos)
            return self._m_tfe_str if hasattr(self, '_m_tfe_str') else None

        @property
        def temp_str(self):
            if hasattr(self, '_m_temp_str'):
                return self._m_temp_str if hasattr(self, '_m_temp_str') else None

            _pos = self._io.pos()
            self._io.seek(134)
            self._m_temp_str = [None] * (2)
            for i in range(2):
                self._m_temp_str[i] = self._io.read_u1()

            self._io.seek(_pos)
            return self._m_temp_str if hasattr(self, '_m_temp_str') else None

        @property
        def volts_str_3(self):
            if hasattr(self, '_m_volts_str_3'):
                return self._m_volts_str_3 if hasattr(self, '_m_volts_str_3') else None

            _pos = self._io.pos()
            self._io.seek(158)
            self._m_volts_str_3 = [None] * (3)
            for i in range(3):
                self._m_volts_str_3[i] = self._io.read_u1()

            self._io.seek(_pos)
            return self._m_volts_str_3 if hasattr(self, '_m_volts_str_3') else None

        @property
        def volt_6(self):
            if hasattr(self, '_m_volt_6'):
                return self._m_volt_6 if hasattr(self, '_m_volt_6') else None

            self._m_volt_6 = (((self.volts_str_6[0] - 48) * 1.0) + ((self.volts_str_6[2] - 48) / 10.0))
            return self._m_volt_6 if hasattr(self, '_m_volt_6') else None

        @property
        def volt_5(self):
            if hasattr(self, '_m_volt_5'):
                return self._m_volt_5 if hasattr(self, '_m_volt_5') else None

            self._m_volt_5 = (((self.volts_str_5[0] - 48) * 1.0) + ((self.volts_str_5[2] - 48) / 10.0))
            return self._m_volt_5 if hasattr(self, '_m_volt_5') else None

        @property
        def uptime(self):
            if hasattr(self, '_m_uptime'):
                return self._m_uptime if hasattr(self, '_m_uptime') else None

            self._m_uptime = (((((((((1 if self.uptime_dd_str[0] > 47 else 0) * (self.uptime_dd_str[0] - 48)) * 10) + (self.uptime_dd_str[1] - 48)) * 24) * 60) * 60) + ((((((1 if self.uptime_hh_str[0] > 47 else 0) * (self.uptime_hh_str[0] - 48)) * 10) + (self.uptime_hh_str[1] - 48)) * 60) * 60)) + (((((1 if self.uptime_mm_str[0] > 47 else 0) * (self.uptime_mm_str[0] - 48)) * 10) + (self.uptime_mm_str[1] - 48)) * 60))
            return self._m_uptime if hasattr(self, '_m_uptime') else None

        @property
        def volts_str_1(self):
            if hasattr(self, '_m_volts_str_1'):
                return self._m_volts_str_1 if hasattr(self, '_m_volts_str_1') else None

            _pos = self._io.pos()
            self._io.seek(150)
            self._m_volts_str_1 = [None] * (3)
            for i in range(3):
                self._m_volts_str_1[i] = self._io.read_u1()

            self._io.seek(_pos)
            return self._m_volts_str_1 if hasattr(self, '_m_volts_str_1') else None

        @property
        def hff_str(self):
            if hasattr(self, '_m_hff_str'):
                return self._m_hff_str if hasattr(self, '_m_hff_str') else None

            _pos = self._io.pos()
            self._io.seek(234)
            self._m_hff_str = self._io.read_u1()
            self._io.seek(_pos)
            return self._m_hff_str if hasattr(self, '_m_hff_str') else None

        @property
        def hr_str(self):
            if hasattr(self, '_m_hr_str'):
                return self._m_hr_str if hasattr(self, '_m_hr_str') else None

            _pos = self._io.pos()
            self._io.seek(255)
            self._m_hr_str = self._io.read_u1()
            self._io.seek(_pos)
            return self._m_hr_str if hasattr(self, '_m_hr_str') else None


    @property
    def frame_length(self):
        if hasattr(self, '_m_frame_length'):
            return self._m_frame_length if hasattr(self, '_m_frame_length') else None

        self._m_frame_length = self._io.size()
        return self._m_frame_length if hasattr(self, '_m_frame_length') else None





"""
`pytest` testing framework file for CAPE-1 decoder
"""

import pytest
import satnogsdecoders.decoder as decoder
from tests.shared_methods import load_objects


def test_answer():
    """
    `pytest` entry point
    """

    valid_packets = [
        [
            # Test payload type 1 (from
            # https://www.pe0sat.vgnet.nl/download/CAPE/cape-1_02-07-2020_1940UTC.PNG,
            # modified to make valid)
            b'K5USL19000EEEF00000000',
            {
                'callsign': 'K5USL',
                'pkt_type': '1',
                'mpb_voltage': 144,
                'hpb_voltage': 0,
                'battery_1_voltage': 238,
                'battery_2_voltage': 239,
                'battery_1_current_generated': 0,
                'battery_1_current_absorbed': 0,
                'battery_2_current_absorbed': 0,
                'battery_2_current_generated': 0
            }
        ],
        [
            # Test payload type 2 (from
            # https://www.pe0sat.vgnet.nl/download/CAPE/cape-1_02-07-2020_1940UTC.PNG)
            b'K5USL200FF1C151E0A1808F5',
            {
                'callsign': 'K5USL',
                'pkt_type': '2',
                'temp_battery_1': 0,
                'temp_px_face': -1,
                'temp_nx_face': 28,
                'temp_py_face': 21,
                'temp_ny_face': 30,
                'temp_pz_face': 10,
                'temp_nz_face': 24,
                'temp_rf_amp': 8,
                'temp_battery_2': -11
            }
        ],
        [
            # Test payload type 3 (from
            # https://www.pe0sat.vgnet.nl/download/CAPE/cape-1_02-07-2020_1940UTC.PNG,
            # modified to make valid)
            b'K5USL3009005000100',
            {
                'callsign': 'K5USL',
                'pkt_type': '3',
                'panel_px_face': 0,
                'panel_nx_face': 144,
                'panel_py_face': 5,
                'panel_ny_face': 0,
                'panel_pz_face': 1,
                'panel_nz_face': 0
            }
        ],
        [
            # Test live payload - data_2482493_2020-07-03T12-17-23
            b'K5USL201FF1F19180D220900E IE 5P ',
            {
                'callsign': 'K5USL',
                'pkt_type': '2',
                'temp_battery_1': 1,
                'temp_px_face': -1,
                'temp_nx_face': 31,
                'temp_py_face': 25,
                'temp_ny_face': 24,
                'temp_pz_face': 13,
                'temp_nz_face': 34,
                'temp_rf_amp': 9,
                'temp_battery_2': 0
            }
        ],
    ]
    invalid_packets = [
        # Payload type 1 with non-hex value
        'K5USL19I00EEEF00000000',
        # Payload type 2 with non-hex value
        'K5USL200FF1C151EXA1808F5',
        # Payload type 3 with non-hex value
        'K5USL3009M05000100',
        # Unexpected callsign
        'K4USL3009M05000100'
    ]
    dut = 'Cape1'
    result = []

    for frame, expected in valid_packets:
        result = load_objects(decoder, dut, frame)
        assert result == expected

    for frame in invalid_packets:
        with pytest.raises(Exception):
            result = load_objects(decoder, dut, frame)
